@@ -380,7 +380,7 @@ PrintPreview.prototype.initScaleCombo = function() {
     for (var i=0; i<scales.length; ++i) {
         scaleCombo.addItem(scales[i]);
     }
-    scaleCombo.currentText = prev;
+    scaleCombo.setEditText(prev);
     scaleCombo.blockSignals(false);
 };
 
